@@ -29,7 +29,6 @@ import java.net.HttpURLConnection;
 import java.net.URL;
 import java.net.URLConnection;
 import java.util.Date;
-import java.util.Iterator;
 
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.Project;
@@ -59,6 +58,9 @@ public class Get extends Task {
     private static final int BIG_BUFFER_SIZE = 100 * 1024;
     private static final FileUtils FILE_UTILS = FileUtils.getFileUtils();
     private static final int REDIRECT_LIMIT = 25;
+    // HttpURLConnection doesn't have a constant for this in Java5 and
+    // what it calls HTTP_MOVED_TEMP would better be FOUND
+    private static final int HTTP_MOVED_TEMP = 307;
 
     private static final String HTTP = "http";
     private static final String HTTPS = "https";
@@ -84,9 +86,8 @@ public class Get extends Task {
     public void execute() throws BuildException {
         checkAttributes();
 
-        for (Iterator iter = sources.iterator(); iter.hasNext(); ) {
-            Resource r = (Resource) iter.next();
-            URLProvider up = (URLProvider) r.as(URLProvider.class);
+        for (Resource r : sources) {
+            URLProvider up = r.as(URLProvider.class);
             URL source = up.getURL();
 
             File dest = destination;
@@ -157,9 +158,8 @@ public class Get extends Task {
     public boolean doGet(int logLevel, DownloadProgress progress)
             throws IOException {
         checkAttributes();
-        for (Iterator iter = sources.iterator(); iter.hasNext(); ) {
-            Resource r = (Resource) iter.next();
-            URLProvider up = (URLProvider) r.as(URLProvider.class);
+        for (Resource r : sources) {
+            URLProvider up = r.as(URLProvider.class);
             URL source = up.getURL();
             return doGet(source, destination, logLevel, progress);
         }
@@ -251,8 +251,8 @@ public class Get extends Task {
             throw new BuildException("at least one source is required",
                                      getLocation());
         }
-        for (Iterator iter = sources.iterator(); iter.hasNext(); ) {
-            Object up = ((Resource) iter.next()).as(URLProvider.class);
+        for (Resource r : sources) {
+            URLProvider up = r.as(URLProvider.class);
             if (up == null) {
                 throw new BuildException("Only URLProvider resources are"
                                          + " supported", getLocation());
@@ -445,7 +445,7 @@ public class Get extends Task {
 
     /**
      * Interface implemented for reporting
-     * progess of downloading.
+     * progress of downloading.
      */
     public interface DownloadProgress {
         /**
@@ -669,7 +669,8 @@ public class Get extends Task {
                 int responseCode = httpConnection.getResponseCode();
                 if (responseCode == HttpURLConnection.HTTP_MOVED_PERM || 
                         responseCode == HttpURLConnection.HTTP_MOVED_TEMP ||
-                        responseCode == HttpURLConnection.HTTP_SEE_OTHER)
+                        responseCode == HttpURLConnection.HTTP_SEE_OTHER ||
+                        responseCode == HTTP_MOVED_TEMP)
                 {
                     String newLocation = httpConnection.getHeaderField("Location");
                     String message = aSource
