@@ -27,6 +27,7 @@ import java.util.Stack;
 import java.util.Vector;
 
 import org.apache.tools.ant.BuildException;
+import org.apache.tools.ant.MagicNames;
 import org.apache.tools.ant.PathTokenizer;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.types.resources.Union;
@@ -52,7 +53,7 @@ import org.apache.tools.ant.util.JavaEnvUtils;
  * &lt;/sometask&gt;<br>
  * </code>
  * <p>
- * The object implemention <code>sometask</code> must provide a method called
+ * The object implementation <code>sometask</code> must provide a method called
  * <code>createSomepath</code> which returns an instance of <code>Path</code>.
  * Nested path definitions are handled by the Path object and must be labeled
  * <code>pathelement</code>.<p>
@@ -78,9 +79,6 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
     public static Path systemBootClasspath =
         new Path(null, System.getProperty("sun.boot.class.path"));
 
-    private static final Iterator EMPTY_ITERATOR
-        = Collections.EMPTY_SET.iterator();
-
     // CheckStyle:VisibilityModifier OFF - bc
 
     /**
@@ -120,7 +118,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
          * Create an iterator.
          * @return an iterator.
          */
-        public Iterator iterator() {
+        public Iterator<Resource> iterator() {
             return new FileResourceIterator(getProject(), null, parts);
         }
 
@@ -396,7 +394,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
      * @return an array of strings, one for each path element
      */
     public static String[] translatePath(Project project, String source) {
-        final Vector result = new Vector();
+        final Vector<String> result = new Vector<String>();
         if (source == null) {
             return new String[0];
         }
@@ -417,9 +415,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
             result.addElement(element.toString());
             element = new StringBuffer();
         }
-        String[] res = new String[result.size()];
-        result.copyInto(res);
-        return res;
+        return result.toArray(new String[result.size()]);
     }
 
     /**
@@ -488,7 +484,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
      * @param p   the project to use to dereference the references.
      * @throws BuildException on error.
      */
-    protected synchronized void dieOnCircularReference(Stack stk, Project p)
+    protected synchronized void dieOnCircularReference(Stack<Object> stk, Project p)
         throws BuildException {
         if (isChecked()) {
             return;
@@ -552,11 +548,11 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
         Path result = new Path(getProject());
 
         String order = defValue;
-        if (getProject() != null) {
-            String o = getProject().getProperty("build.sysclasspath");
-            if (o != null) {
-                order = o;
-            }
+        String o = getProject() != null
+            ? getProject().getProperty(MagicNames.BUILD_SYSCLASSPATH)
+            : System.getProperty(MagicNames.BUILD_SYSCLASSPATH);
+        if (o != null) {
+            order = o;
         }
         if (order.equals("only")) {
             // only: the developer knows what (s)he is doing
@@ -574,7 +570,8 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
         } else {
             // last: don't trust the developer
             if (!order.equals("last")) {
-                log("invalid value for build.sysclasspath: " + order,
+                log("invalid value for " + MagicNames.BUILD_SYSCLASSPATH
+                    + ": " + order,
                     Project.MSG_WARN);
             }
             result.addExisting(this);
@@ -699,7 +696,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
      * are added to this container while the Iterator is in use.
      * @return a "fail-fast" Iterator.
      */
-    public final synchronized Iterator iterator() {
+    public final synchronized Iterator<Resource> iterator() {
         if (isReference()) {
             return ((Path) getCheckedRef()).iterator();
         }
@@ -707,7 +704,7 @@ public class Path extends DataType implements Cloneable, ResourceCollection {
         if (getPreserveBC()) {
             return new FileResourceIterator(getProject(), null, list());
         }
-        return union == null ? EMPTY_ITERATOR
+        return union == null ? Collections.<Resource> emptySet().iterator()
             : assertFilesystemOnly(union).iterator();
     }
 
